## Generated automatically. Do not edit! -*- shell-script -*-
{% for fn in log_functions %}
v{{ fn }}() {
	if test x"${VERBOSE:-yes}" != x"no" ; then
		{{ fn }} "$@"
	else
		true
	fi
}
{% endfor %}
{% for fn in log_end_functions %}
v{{ fn }}() {
	if test x"${VERBOSE:-yes}" != x"no" ; then
		{{ fn }} "$@"
	else
		return ${1:-1}
	fi
}
{% endfor %}
# vim: ft=sh
